﻿using System;
using System.Windows.Input;

namespace HiveManager
{
	public class DelegateCommand : ICommand
	{
		private Action execute;
		private Func<bool> canExecute;

		public DelegateCommand(Action execute, Func<bool> canExecute)
		{
			this.execute = execute;
			this.canExecute = canExecute;
		}

		public bool CanExecute(object parameter)
		{
			if (this.canExecute != null)
			{
				return this.canExecute();
			}

			return true;
		}

		public void RaiseCanExecuteChanged()
		{
			if (this.CanExecuteChanged != null)
			{
				this.CanExecuteChanged(this, EventArgs.Empty);
			}
		}

		public event EventHandler CanExecuteChanged;

		public void Execute(object parameter)
		{
			if (this.execute != null)
			{
				this.execute();
			}
		}
	}
}
